@@ -1,7 +1,7 @@
 /*
 # C-Code for searching and merging
 # S3 atomic 64bit integers for R
-# (c) 2011 Jens Oehlschgel
+# (c) 2011 Jens Oehlschägel
 # Licence: GPL2
 # Provided 'as is', use at your own risk
 # Created: 2011-12-11
@@ -677,6 +677,7 @@ SEXP r_ram_integer64_ordertab_asc(
   IndexT * ret = INTEGER(ret_);
   int cnt;
   if (n){
+	  PROTECT(ret_); /* because of R_Busy wee need PROTECT, according to Thomas Kalibera */  
 	  R_Busy(1);
 	  if (asLogical(denormalize_)){
 	      j = 0;
@@ -727,6 +728,7 @@ SEXP r_ram_integer64_ordertab_asc(
 		  }
 	  }
 	  R_Busy(0);
+	  UNPROTECT(1);
   }
   return ret_;
 }
@@ -745,6 +747,7 @@ SEXP r_ram_integer64_sortordertab_asc(
   IndexT * ret = INTEGER(ret_);
   int cnt;
   if (n){
+          PROTECT(ret_); /* because of R_Busy wee need PROTECT, according to Thomas Kalibera */
 	  R_Busy(1);
 	  if (asLogical(denormalize_)){
 			  pos = 0;
@@ -780,6 +783,7 @@ SEXP r_ram_integer64_sortordertab_asc(
 			  SET_LENGTH(ret_, pos);
 	  }
 	  R_Busy(0);
+          UNPROTECT(1);
   }
   return ret_;
 }
